@@ -2,7 +2,7 @@
  *
  * $Id: definition.h,v 1.21 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -120,7 +120,7 @@ class Definition : public DefinitionIntf, public LockableObj
 
     /*! Returns the fully qualified name of this definition
      */
-    virtual QCString qualifiedName();
+    virtual QCString qualifiedName() const;
 
     /*! Returns the name of this definition as it appears in the symbol map.
      */
@@ -156,6 +156,16 @@ class Definition : public DefinitionIntf, public LockableObj
     /*! Returns the line number at which the brief description was found. */
     int briefLine() const;
 
+    /*! Returns the documentation found inside the body of a member */
+    QCString inbodyDocumentation() const;
+
+    /*! Returns the file in which the in body documentation was found */
+    QCString inbodyFile() const;
+
+    /*! Returns the line at which the first in body documentation 
+        part was found */
+    int inbodyLine() const;
+
     /*! Returns the file in which the brief description was found. 
      *  This can differ from getDefFileName().
      */
@@ -164,7 +174,7 @@ class Definition : public DefinitionIntf, public LockableObj
     /*! returns the file in which this definition was found */
     QCString getDefFileName() const;
 
-    /*! returns the file in which this definition was found */
+    /*! returns the extension of the file in which this definition was found */
     QCString getDefFileExtension() const;
 
     /*! returns the line number at which the definition was found */
@@ -200,6 +210,11 @@ class Definition : public DefinitionIntf, public LockableObj
     /*! Returns TRUE iff this item is supposed to be hidden from the output. */
     bool isHidden() const;
 
+    /*! returns TRUE if this entity was artificially introduced, for 
+     *  instance because it is used to show a template instantiation relation. 
+     */
+    bool isArtificial() const;
+
     /*! If this definition was imported via a tag file, this function
      *  returns the tagfile for the external project. This can be
      *  translated into an external link target via 
@@ -240,7 +255,7 @@ class Definition : public DefinitionIntf, public LockableObj
     //-----------------------------------------------------------------------------------
 
     /*! Sets a new \a name for the definition */
-    void setName(const char *name) { m_name = name; }
+    void setName(const char *name);
 
     /*! Sets the documentation of this definition to \a d. */
     void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
@@ -250,6 +265,12 @@ class Definition : public DefinitionIntf, public LockableObj
      */
     void setBriefDescription(const char *b,const char *briefFile,int briefLine);
 
+    /*! Set the documentation that was found inside the body of an item.
+     *  If there was already some documentation set, the new documentation
+     *  will be appended.
+     */
+    void setInbodyDocumentation(const char *d,const char *docFile,int docLine);
+
     /*! Sets the tag file id via which this definition was imported. */
     void setReference(const char *r);
 
@@ -271,6 +292,8 @@ class Definition : public DefinitionIntf, public LockableObj
 
     void setHidden(bool b);
 
+    void setArtificial(bool b);
+
     //-----------------------------------------------------------------------------------
     // --- actions ----
     //-----------------------------------------------------------------------------------
@@ -310,7 +333,9 @@ class Definition : public DefinitionIntf, public LockableObj
     void _writeSourceRefList(OutputList &ol,const char *scopeName,
                        const QCString &text,MemberSDict *members,bool);
     void _setBriefDescription(const char *b,const char *briefFile,int briefLine);
-    void _setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace);
+    void _setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace,bool atTop);
+    void _setInbodyDocumentation(const char *d,const char *docFile,int docLine);
+    bool _docsAlreadyAdded(const QString &doc);
     DefinitionImpl *m_impl; // internal structure holding all private data
     QCString m_name;
     bool m_isSymbol;
