@@ -3,7 +3,7 @@
  * $Id: diagram.h,v 1.11 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -123,9 +123,9 @@ class ClassDiagram
     ClassDiagram(ClassDef *root);
    ~ClassDiagram();
     void writeFigure(QTextStream &t,const char *path,
-                     const char *file);
+                     const char *file) const;
     void writeImage(QTextStream &t,const char *path,const char *relPath,
-                     const char *file,bool generateMap=TRUE);
+                     const char *file,bool generateMap=TRUE) const;
   private:
     TreeDiagram *base;
     TreeDiagram *super;
