@@ -2,7 +2,7 @@
  *
  * $Id: htmlhelp.cpp,v 1.8 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,12 +22,15 @@
 #include <stdlib.h>
 #include <qlist.h>
 #include <qdict.h>
+#include <qregexp.h>
+#include "qtextcodec.h"
 
 #include "htmlhelp.h"
 #include "config.h"
 #include "message.h"
 #include "doxygen.h"
 #include "language.h"
+#include "portable.h"
 
 //----------------------------------------------------------------------------
 
@@ -115,6 +118,10 @@ void HtmlHelpIndex::addItem(const char *level1,const char *level2,
 {
   QCString key = level1; 
   if (level2) key+= (QCString)"?" + level2;
+  if (key.find(QRegExp("@[0-9]+"))!=-1) // skip anonymous stuff
+  {
+    return;
+  }
   if (dict->find(key)==0) // new key
   {
     //printf(">>>>>>>>> HtmlHelpIndex::addItem(%s,%s,%s,%s)\n",
@@ -268,8 +275,14 @@ HtmlHelp::HtmlHelp() : indexFileDict(1009)
   dc = 0;
   cf = kf = 0;
   index = new HtmlHelpIndex;
+  m_fromUtf8 = (void *)(-1);
 }
 
+HtmlHelp::~HtmlHelp()
+{
+  if (m_fromUtf8!=(void *)(-1))   portable_iconv_close(m_fromUtf8);
+}
+#if 0
 /*! return a reference to the one and only instance of this class. 
  */
 HtmlHelp *HtmlHelp::getInstance()
@@ -277,6 +290,7 @@ HtmlHelp *HtmlHelp::getInstance()
   if (theInstance==0) theInstance = new HtmlHelp;
   return theInstance;
 }
+#endif
 
 static QDict<QCString> s_languageDict;
 
@@ -287,6 +301,10 @@ static QDict<QCString> s_languageDict;
  */
 void HtmlHelp::initialize()
 {
+  const char *str = Config_getString("CHM_INDEX_ENCODING");
+  if(!str) str = "Windows-1250";
+  m_fromUtf8 = portable_iconv_open(str,"UTF-8"); 
+
   /* open the contents file */
   QCString fName = Config_getString("HTML_OUTPUT") + "/index.hhc";
   cf = new QFile(fName);
@@ -297,9 +315,7 @@ void HtmlHelp::initialize()
   }
   /* Write the header of the contents file */
   cts.setDevice(cf);
-#if QT_VERSION >= 200
   cts.setEncoding(QTextStream::Latin1);
-#endif
   cts << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">\n"
          "<HTML><HEAD></HEAD><BODY>\n"
          "<OBJECT type=\"text/site properties\">\n"
@@ -317,9 +333,7 @@ void HtmlHelp::initialize()
   }
   /* Write the header of the contents file */
   kts.setDevice(kf);
-#if QT_VERSION >= 200
   kts.setEncoding(QTextStream::Latin1);
-#endif
   kts << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">\n"
          "<HTML><HEAD></HEAD><BODY>\n"
          "<OBJECT type=\"text/site properties\">\n"
@@ -417,7 +431,7 @@ void HtmlHelp::createProjectFile()
    
     
     QCString indexName="index"+Doxygen::htmlFileExtension;
-    if (Config_getBool("GENERATE_TREEVIEW")) indexName="main"+Doxygen::htmlFileExtension;
+    if (usingTreeIndex()) indexName="main"+Doxygen::htmlFileExtension;
     t << "[OPTIONS]\n";
     if (!Config_getString("CHM_FILE").isEmpty())
     {
@@ -432,12 +446,19 @@ void HtmlHelp::createProjectFile()
          "Language=" << getLanguageString() << endl;
     if (Config_getBool("BINARY_TOC")) t << "Binary TOC=YES\n";
     if (Config_getBool("GENERATE_CHI")) t << "Create CHI file=YES\n";
-    t << "Title=" << Config_getString("PROJECT_NAME") << endl << endl;
+    t << "Title=" << recode(Config_getString("PROJECT_NAME")) << endl << endl;
     
     t << "[WINDOWS]" << endl;
-    t << "main=\"" << Config_getString("PROJECT_NAME") << "\",\"index.hhc\","
+
+    // NOTE: the 0x10387e number is a set of bits specifying the buttons
+    //       which should appear in the CHM viewer; that specific value
+    //       means "show all buttons including the font-size one";
+    //       the font-size one is not normally settable by the HTML Help Workshop
+    //       utility but the way to set it is described here:
+    //          http://support.microsoft.com/?scid=kb%3Ben-us%3B240062&x=17&y=18
+    t << "main=\"" << recode(Config_getString("PROJECT_NAME")) << "\",\"index.hhc\","
          "\"index.hhk\",\"" << indexName << "\",\"" << 
-         indexName << "\",,,,,0x23520,,0x387e,,,,,,,,0" << endl << endl;
+         indexName << "\",,,,,0x23520,,0x10387e,,,,,,,,0" << endl << endl;
     
     t << "[FILES]" << endl;
     char *s = indexFiles.first();
@@ -450,6 +471,11 @@ void HtmlHelp::createProjectFile()
     t << "tab_b.gif" << endl;
     t << "tab_l.gif" << endl;
     t << "tab_r.gif" << endl;
+    if (Config_getBool("HTML_DYNAMIC_SECTIONS"))
+    {
+      t << "open.gif" << endl;
+      t << "closed.gif" << endl;
+    }
     f.close();
   }
   else
@@ -475,6 +501,8 @@ void HtmlHelp::finalize()
 {
   // end the contents file
   cts << "</UL>\n";
+  cts << "</BODY>\n";
+  cts << "</HTML>\n";
   cts.unsetDevice();
   cf->close();
   delete cf;
@@ -483,6 +511,8 @@ void HtmlHelp::finalize()
   
   // end the index file
   kts << "</UL>\n";
+  kts << "</BODY>\n";
+  kts << "</HTML>\n";
   kts.unsetDevice();
   kf->close();
   delete kf;
@@ -495,47 +525,71 @@ void HtmlHelp::finalize()
  *  This will start a new unnumbered HTML list in contents file.
  *  \sa decContentsDepth()
  */
-int HtmlHelp::incContentsDepth()
+void HtmlHelp::incContentsDepth()
 {
   int i; for (i=0;i<dc+1;i++) cts << "  ";
   cts << "<UL>\n";
-  return ++dc;
+  ++dc;
 }
 
 /*! Decrease the level of the contents hierarchy.
  *  This will end the unnumber HTML list.
  *  \sa incContentsDepth()
  */
-int HtmlHelp::decContentsDepth()
+void HtmlHelp::decContentsDepth()
 {
   int i; for (i=0;i<dc;i++) cts << "  ";
   cts << "</UL>\n";
-  return --dc;
+  --dc;
+}
+
+QCString HtmlHelp::recode(const QCString &s) 
+{
+  int iSize        = s.length();
+  int oSize        = iSize*4+1;
+  QCString output(oSize);
+  size_t iLeft     = iSize;
+  size_t oLeft     = oSize;
+  const char *iPtr = s.data();
+  char *oPtr       = output.data();
+  if (!portable_iconv(m_fromUtf8,&iPtr,&iLeft,&oPtr,&oLeft))
+  {
+    oSize -= oLeft;
+    output.resize(oSize+1);
+    output.at(oSize)='\0';
+    return output;
+  }
+  else
+  {
+    return s;
+  }
 }
 
 /*! Add an list item to the contents file.
  *  \param isDir boolean indicating if this is a dir or file entry
  *  \param name the name of the item.
  *  \param ref  the URL of to the item.
+ *  \param file the file in which the item is defined.
  *  \param anchor the anchor of the item.
  */
 void HtmlHelp::addContentsItem(bool isDir,
-                               const char *name,const char *ref, 
+                               const char *name,
+                               const char * /*ref*/, 
+                               const char *file,
                                const char *anchor)
 {
   // If we're using a binary toc then folders cannot have links. 
   if(Config_getBool("BINARY_TOC") && isDir) 
   {
-    ref = 0;
+    file = 0;
     anchor = 0;
   }
-  
   int i; for (i=0;i<dc;i++) cts << "  ";
   cts << "<LI><OBJECT type=\"text/sitemap\">";
-  cts << "<param name=\"Name\" value=\"" << name << "\">";
-  if (ref)      // made ref optional param - KPW
+  cts << "<param name=\"Name\" value=\"" << recode(name) << "\">";
+  if (file)      // made file optional param - KPW
   {
-    cts << "<param name=\"Local\" value=\"" << ref << Doxygen::htmlFileExtension;
+    cts << "<param name=\"Local\" value=\"" << file << Doxygen::htmlFileExtension;
     if (anchor) cts << "#" << anchor;  
     cts << "\">";
   }
@@ -558,12 +612,14 @@ void HtmlHelp::addContentsItem(bool isDir,
  *  \param contRef the output file refering to the container.
  *  \param memRef  the output file containing to the member documentation.
  *  \param anchor  the anchor of the item.
+ *  \param md      the member definition corresponding to this item.
  *  \sa HtmlHelpIndex
  */
 void HtmlHelp::addIndexItem(const char *level1, const char *level2,
                             const char *contRef, const char *memRef, 
-                            const char *anchor)
+                            const char *anchor,const MemberDef *md)
 {
+  (void)md;
   index->addItem(level1,level2,contRef,anchor,TRUE,FALSE);
   index->addItem(level2,level1,memRef,anchor,TRUE,TRUE);
 }
