@@ -78,6 +78,8 @@ class HtmlHelp  : public IndexIntf
                       const char *contRef, const char *memRef,
                       const char *anchor,const MemberDef *md);
     void addIndexFile(const char *name);
+    void addImageFile(const char *) {}
+    void addStyleSheetFile(const char *) {}
 
   private:
     void createProjectFile();
