@@ -30,3 +30,7 @@
 #define LANG_CA
 #define LANG_LT
 #define LANG_ZA
+#define LANG_AR
+#define LANG_FA
+#define LANG_VI
+#define LANG_TR
