@@ -134,6 +134,12 @@
 #ifdef LANG_SC
 #include "translator_sc.h"
 #endif
+#ifdef LANG_VI
+#include "translator_vi.h"
+#endif
+#ifdef LANG_TR
+#include "translator_tr.h"
+#endif
 #endif // !ENGLISH_ONLY
 
 #define L_EQUAL(a) !stricmp(langName,a)
@@ -373,6 +379,18 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorMacedonian;
   }
 #endif
+#ifdef LANG_VI
+  else if (L_EQUAL("vietnamese"))
+  {
+    theTranslator=new TranslatorVietnamese;
+  }
+#endif
+#ifdef LANG_TR
+  else if (L_EQUAL("turkish"))
+  {
+    theTranslator=new TranslatorTurkish;
+  }
+#endif
 #endif // ENGLISH_ONLY
   else // use the default language (i.e. english)
   {
