@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -259,7 +259,7 @@ void RTFDocVisitor::visit(DocLineBreak *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visit(DocLineBreak)}\n");
-  m_t << "\\par\n";
+  m_t << "\\par";
   m_lastIsPara=TRUE;
 }
 
@@ -310,7 +310,7 @@ void RTFDocVisitor::visit(DocStyleChange *s)
       else
       {
         m_insidePre=FALSE;
-        m_t << "\\par" << endl; 
+        m_t << "\\par";
         m_t << "}" << endl;
       }
       m_lastIsPara=TRUE;
@@ -442,7 +442,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
                                            inc->text().latin1(),
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
-         m_t << "\\par" << endl; 
+         m_t << "\\par";
          m_t << "}" << endl;
       }
       break;
@@ -454,7 +454,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
                             ->parseCode(m_ci,inc->context(),
                                         inc->text().latin1(),inc->isExample(),
                                         inc->exampleFile());
-      m_t << "\\par" << endl; 
+      m_t << "\\par";
       m_t << "}" << endl;
       break;
     case DocInclude::DontInclude: 
@@ -466,7 +466,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
       filter(inc->text());
-      m_t << "\\par" << endl; 
+      m_t << "\\par";
       m_t << "}" << endl;
       break;
   }
@@ -506,7 +506,7 @@ void RTFDocVisitor::visit(DocIncOperator *op)
     popEnabled();
     if (!m_hide)
     {
-      m_t << "\\par" << endl; 
+      m_t << "\\par";
       m_t << "}" << endl;
     }
     m_lastIsPara=TRUE;
@@ -553,7 +553,7 @@ void RTFDocVisitor::visitPost(DocAutoList *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocAutoList)}\n");
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}" << endl;
   m_lastIsPara=TRUE;
 }
@@ -593,7 +593,8 @@ void RTFDocVisitor::visitPost(DocPara *p)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocPara)}\n");
-  if (!p->isLast() &&            // omit <p> for last paragraph
+  if (!m_lastIsPara &&
+      !p->isLast() &&            // omit <p> for last paragraph
       !(p->parent() &&           // and for parameters & sections
         p->parent()->kind()==DocNode::Kind_ParamSect
        )
@@ -669,7 +670,7 @@ void RTFDocVisitor::visitPre(DocSimpleSect *s)
   if (s->type()!=DocSimpleSect::User && s->type()!=DocSimpleSect::Rcs)
   {
     m_t << ":";
-    m_t << "\\par" << endl;
+    m_t << "\\par";
     m_t << "}"; // end bold
     incIndentLevel();
     m_t << rtf_Style_Reset << getStyle("DescContinue");
@@ -779,7 +780,7 @@ void RTFDocVisitor::visitPost(DocHtmlList *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocHtmlList)}\n");
-  m_t << "\\par" << endl << "}" << endl;
+  m_t << "\\par" << "}" << endl;
   m_lastIsPara=TRUE;
 }
 
@@ -858,7 +859,7 @@ void RTFDocVisitor::visitPost(DocHtmlDescData *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocHtmlDescData)}\n");
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}" << endl;
   decIndentLevel();
   m_lastIsPara=TRUE;
@@ -894,7 +895,7 @@ void RTFDocVisitor::visitPre(DocHtmlRow *r)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocHtmlRow)}\n");
-  uint i,columnWidth=rtf_pageWidth/r->numCells();
+  uint i,columnWidth=r->numCells()>0 ? rtf_pageWidth/r->numCells() : 10;
   m_t << "\\trowd \\trgaph108\\trleft-108"
          "\\trbrdrt\\brdrs\\brdrw10 "
          "\\trbrdrl\\brdrs\\brdrw10 "
@@ -959,7 +960,7 @@ void RTFDocVisitor::visitPost(DocInternal *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocInternal)}\n");
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   decIndentLevel();
   m_t << "}"; // end desc
   m_lastIsPara=TRUE;
@@ -1025,7 +1026,7 @@ void RTFDocVisitor::visitPost(DocHtmlHeader *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocHtmlHeader)}\n");
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}" << endl; // end section
   m_lastIsPara=TRUE;
 }
@@ -1131,8 +1132,8 @@ void RTFDocVisitor::visitPost(DocSecRefList *)
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocSecRefList)}\n");
   decIndentLevel();
-  m_t << "\\par" << endl;
-  m_t << "}";
+  m_t << "\\par";
+  m_t << "}" << endl;
   m_lastIsPara=TRUE;
 }
 
@@ -1173,11 +1174,16 @@ void RTFDocVisitor::visitPre(DocParamSect *s)
       m_t << theTranslator->trReturnValues(); break;
     case DocParamSect::Exception: 
       m_t << theTranslator->trExceptions(); break;
+    case DocParamSect::TemplateParam: 
+      /* TODO: add this 
+      m_t << theTranslator->trTemplateParam(); break;
+      */
+      m_t << "Template Parameters"; break;
     default:
       ASSERT(0);
   }
   m_t << ":";
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}" << endl;
   incIndentLevel();
   m_t << rtf_Style_Reset << getStyle("DescContinue");
@@ -1197,6 +1203,26 @@ void RTFDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocParamList)}\n");
+
+  // Put in the direction: in/out/in,out if specified.
+  if (pl->direction()!=DocParamSect::Unspecified)
+  {
+    m_t << "[";
+    if (pl->direction()==DocParamSect::In)
+    {
+      m_t << "in";
+    }
+    else if (pl->direction()==DocParamSect::Out)
+    {
+      m_t << "out";
+    }
+    else if (pl->direction()==DocParamSect::InOut)
+    {
+      m_t << "in,out";
+    }
+    m_t << "] ";
+  }
+
   m_t << "{\\i ";
   //QStrListIterator li(pl->parameters());
   //const char *s;
@@ -1268,7 +1294,7 @@ void RTFDocVisitor::visitPre(DocXRefItem *x)
     filter(x->title());
   }
   m_t << ":";
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}"; // end bold
   incIndentLevel();
   m_t << rtf_Style_Reset << getStyle("DescContinue");
