@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -14,7 +14,7 @@
  * input used in their production; they are not affected by this license.
  *
  * The translation into Chinesetraditional was provided by
- *   Daniel YC Lin (daniel@twpda.com) since v1.2.16
+ *   Daniel YC Lin (dlin.tw <at> gmail.com) since v1.2.16-v1.5.5
  */
 
 #ifndef TRANSLATOR_TW_H
@@ -41,7 +41,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
+class TranslatorChinesetraditional : public Translator
 {
   public:
 
@@ -191,10 +191,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
     virtual QCString trFileList()
     { return "ɮצC"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return "Yɮ"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
@@ -326,10 +322,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return "զAPIY:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return "ҦdҦC:"; }
@@ -342,12 +334,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
     virtual QCString trModulesDescription()
     { return "ҦҲզC:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return "SiΪyz"; }
-
     // index titles (the project name is prepended for these)
 
 
@@ -557,18 +543,10 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
     virtual QCString trForInternalUseOnly()
     { return "ȨѤϥ."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return "]]s@; vTAPI."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "ĵi"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return "Τέ"; }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return ""; }
@@ -646,8 +624,8 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
         case ClassDef::Struct:     result+=" c"; break;
         case ClassDef::Union:      result+=" pX"; break;
         case ClassDef::Interface:  result+=" "; break;
-        case ClassDef::Protocol:   result+=" protocol"; break; // translate me!
-        case ClassDef::Category:   result+=" category"; break; // translate me!
+        case ClassDef::Protocol:   result+=" w"; break; 
+        case ClassDef::Category:   result+=" "; break;
         case ClassDef::Exception:  result+=" ҥ~"; break;
       }
       if (isTemplate) result+=" ˪";
@@ -805,8 +783,8 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
         case ClassDef::Struct:     result+="c(structure)"; break;
         case ClassDef::Union:      result+="pX(union)"; break;
         case ClassDef::Interface:  result+="(interface)"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
+        case ClassDef::Protocol:   result+="w(protocol)"; break;
+        case ClassDef::Category:   result+="(category)"; break;
         case ClassDef::Exception:  result+="ҥ~(exception)"; break;
       }
       result+=" OѤUCɮפ";
@@ -843,10 +821,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "lX";
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return "wqb @1 ɮפ @0 .";
@@ -1153,11 +1127,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1190,11 +1159,7 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
     {
       return "Packages";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Package";
-    }
+
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1319,15 +1284,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
       return QCString("");
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
-     *  of the category.
-     */
-    virtual QCString trField(bool /*first_capital*/, bool /*singular*/)
-    {
-      return QCString("");
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
@@ -1593,6 +1549,211 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_4_6
        return "oO@ӬFKQʩҴ overload ơA"
               "ubѼƤWAPe@ӨƤP.";
     }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "IsƪƦC:";
+    }
+
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.5.4 (mainly for Fortran)
+//////////////////////////////////////////////////////////////////////////
+    
+    /*! header that is put before the list of member subprograms (Fortran). */
+    virtual QCString trMemberFunctionDocumentationFortran()
+    { return "/l{ "; }
+
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    virtual QCString trCompoundListFortran()
+    { return "ƫAC"; }
+
+    /*! This is put above each page as a link to all members of compounds (Fortran). */
+    virtual QCString trCompoundMembersFortran()
+    { return ""; }
+
+    /*! This is an introduction to the annotated compound list (Fortran). */
+    virtual QCString trCompoundListDescriptionFortran()
+    { return "ƫA²uC:"; }
+
+    /*! This is an introduction to the page with all data types (Fortran). */
+    virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
+    {
+      QCString result="BCXҦ";
+      if (!extractAll)
+      {
+        result+="";
+      }
+      result+="ƫO";
+      result+=" as ";
+      if (!extractAll) 
+      {
+         result+="CӦƪƵc";
+      }
+      else 
+      {
+         result+="Lݩ󪺸ƫO";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     * annotated compound index (Fortran).
+     */
+    virtual QCString trCompoundIndexFortran()
+    { return "ƫO"; }
+
+    /*! This is used in LaTeX as the title of the chapter containing
+     *  the documentation of all data types (Fortran).
+     */
+    virtual QCString trTypeDocumentation()
+    { return "ƫO"; }
+
+    /*! This is used in the documentation of a file as a header before the 
+     *  list of (global) subprograms (Fortran).
+     */
+    virtual QCString trSubprograms()
+    { return "/l{"; }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for subprograms (Fortran)
+     */
+    virtual QCString trSubprogramDocumentation()
+    { return "/l{ "; }
+
+    /*! This is used in the documentation of a file/namespace/group before 
+     *  the list of links to documented compounds (Fortran)
+     */
+     virtual QCString trDataTypes()
+    { return "ƫO"; }
+    
+    /*! used as the title of page containing all the index of all modules (Fortran). */
+    virtual QCString trModulesList()
+    { return "ҲզC"; }
+
+    /*! used as an introduction to the modules list (Fortran) */
+    virtual QCString trModulesListDescription(bool extractAll)
+    {
+      QCString result="BCXҦ";
+      if (!extractAll) result+="";
+      result+="Ҳժa²u:";
+      return result;
+    }
+
+    /*! used as the title of the HTML page of a module/type (Fortran) */
+    virtual QCString trCompoundReferenceFortran(const char *clName,
+                                    ClassDef::CompoundType compType,
+                                    bool isTemplate)
+    {
+      QCString result=(QCString)clName;
+      switch(compType)
+      {
+        case ClassDef::Class:      result+="Ҳ"; break;
+        case ClassDef::Struct:     result+="A"; break;
+        case ClassDef::Union:      result+="pX"; break;
+        case ClassDef::Interface:  result+=""; break;
+        case ClassDef::Protocol:   result+="ĳ"; break;
+        case ClassDef::Category:   result+=""; break;
+        case ClassDef::Exception:  result+="ҥ~"; break;
+      }
+      if (isTemplate) result+=" Template";
+      result+="ѦҤ";
+      return result;
+    }
+    /*! used as the title of the HTML page of a module (Fortran) */
+    virtual QCString trModuleReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      result+="ҲհѦҤ";
+      return result;
+    }
+    
+    /*! This is put above each page as a link to all members of modules. (Fortran) */
+    virtual QCString trModulesMembers()
+    { return "Ҳզ"; }
+
+    /*! This is an introduction to the page with all modules members (Fortran) */
+    virtual QCString trModulesMemberDescription(bool extractAll)
+    { 
+      QCString result="BCXҦ";
+      if (!extractAll) result+="";
+      result+="Ҳզas";
+      if (extractAll) 
+      {
+        result+="CӨƪҲդ:";
+      }
+      else 
+      {
+        result+="L̩ݪҲ:";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     *  index of all modules (Fortran).
+     */
+    virtual QCString trModulesIndex()
+    { return "Ҳկ"; }
+    
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trModule(bool /* first_capital */, bool /* singular */)
+    {       
+      QCString result("Ҳ");
+      return result; 
+    }
+    /*! This is put at the bottom of a module documentation page and is
+     *  followed by a list of files that were used to generate the page.
+     */
+    virtual QCString trGeneratedFromFilesFortran(ClassDef::CompoundType compType,
+        bool /* single */)
+    { // here s is one of " Module", " Struct" or " Union"
+      // single is true implies a single file
+      QCString result=(QCString)"o";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+="Ҳ"; break;
+        case ClassDef::Struct:     result+="A"; break;
+        case ClassDef::Union:      result+="pX"; break;
+        case ClassDef::Interface:  result+=""; break;
+        case ClassDef::Protocol:   result+="ĳ"; break;
+        case ClassDef::Category:   result+=""; break;
+        case ClassDef::Exception:  result+="ҥ~"; break;
+      }
+      result+="ѤUCɮײ";
+      return result;
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trType(bool /* first_capital */, bool /* singular */)
+    { 
+      QCString result("O");
+      return result; 
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trSubprogram(bool /* first_capital */, bool /* singular */)
+    { 
+      QCString result("l{");
+      return result; 
+    }
+
+    /*! C# Type Constraint list */
+    virtual QCString trTypeConstraints()
+    {
+      return "O";
+    }
+
 };
 
 #endif
