@@ -3,7 +3,7 @@
  * $Id: xml.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -39,6 +39,7 @@
 #include <qdir.h>
 #include <qfile.h>
 #include <qtextstream.h>
+#include <qintdict.h>
 
 // no debug info
 #define XML_DB(x) do {} while(0)
@@ -61,6 +62,51 @@ static const char compound_xsd[] =
 
 //------------------
 
+class XmlSectionMapper : public QIntDict<char>
+{
+  public:
+    XmlSectionMapper() : QIntDict<char>(47)
+    {
+      insert(MemberList::pubTypes,"public-type");
+      insert(MemberList::pubMethods,"public-func");
+      insert(MemberList::pubAttribs,"public-attrib");
+      insert(MemberList::pubSlots,"public-slot");
+      insert(MemberList::signals,"signal");
+      insert(MemberList::dcopMethods,"dcop-func");
+      insert(MemberList::properties,"property");
+      insert(MemberList::events,"event");
+      insert(MemberList::pubStaticMethods,"public-static-func");
+      insert(MemberList::pubStaticAttribs,"public-static-attrib");
+      insert(MemberList::proTypes,"protected-type");
+      insert(MemberList::proMethods,"protected-func");
+      insert(MemberList::proAttribs,"protected-attrib");
+      insert(MemberList::proSlots,"protected-slot");
+      insert(MemberList::proStaticMethods,"protected-static-func");
+      insert(MemberList::proStaticAttribs,"protected-static-attrib");
+      insert(MemberList::pacTypes,"package-type");
+      insert(MemberList::pacMethods,"package-func");
+      insert(MemberList::pacAttribs,"package-attrib");
+      insert(MemberList::pacStaticMethods,"package-static-func");
+      insert(MemberList::pacStaticAttribs,"package-static-attrib");
+      insert(MemberList::priTypes,"private-type");
+      insert(MemberList::priMethods,"private-func");
+      insert(MemberList::priAttribs,"private-attrib");
+      insert(MemberList::priSlots,"private-slot");
+      insert(MemberList::priStaticMethods,"private-static-func");
+      insert(MemberList::priStaticAttribs,"private-static-attrib");
+      insert(MemberList::friends,"friend");
+      insert(MemberList::related,"related");
+      insert(MemberList::decDefineMembers,"define");
+      insert(MemberList::decProtoMembers,"prototype");
+      insert(MemberList::decTypedefMembers,"typedef");
+      insert(MemberList::decEnumMembers,"enum");
+      insert(MemberList::decFuncMembers,"func");
+      insert(MemberList::decVarMembers,"var");
+    }
+};
+
+static XmlSectionMapper g_xmlSectionMapper;
+
 
 inline void writeXMLString(QTextStream &t,const char *s)
 {
@@ -96,8 +142,7 @@ inline void writeXMLCodeString(QTextStream &t,const char *s, int &col)
 
 static void writeXMLHeader(QTextStream &t)
 {
-  t << "<?xml version='1.0' encoding='" << theTranslator->idLanguageCharset()
-    << "' standalone='no'?>" << endl;;
+  t << "<?xml version='1.0' encoding='UTF-8' standalone='no'?>" << endl;;
   t << "<doxygen xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" ";
   t << "xsi:noNamespaceSchemaLocation=\"compound.xsd\" ";
   t << "version=\"" << versionString << "\">" << endl;
@@ -114,7 +159,7 @@ static void writeCombineScript()
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   t <<
   "<!-- XSLT script to combine the generated output into a single file. \n"
@@ -136,7 +181,7 @@ static void writeCombineScript()
 }
 
 void writeXMLLink(QTextStream &t,const char *extRef,const char *compoundId,
-                  const char *anchorId,const char *text)
+                  const char *anchorId,const char *text,const char *tooltip)
 {
   t << "<ref refid=\"" << compoundId;
   if (anchorId) t << "_1" << anchorId;
@@ -144,6 +189,7 @@ void writeXMLLink(QTextStream &t,const char *extRef,const char *compoundId,
   if (anchorId) t << "member"; else t << "compound"; 
   t << "\"";
   if (extRef) t << " external=\"" << extRef << "\"";
+  if (tooltip) t << " tooltip=\"" << convertToXML(tooltip) << "\"";
   t << ">";
   writeXMLString(t,text);
   t << "</ref>";
@@ -162,7 +208,7 @@ class TextGeneratorXMLImpl : public TextGeneratorIntf
                    const char *anchor,const char *text
                   ) const
     {
-      writeXMLLink(m_t,extRef,file,anchor,text);
+      writeXMLLink(m_t,extRef,file,anchor,text,0);
     }
   private:
     QTextStream &m_t;
@@ -242,7 +288,8 @@ class XMLCodeGenerator : public CodeOutputInterface
       writeXMLCodeString(m_t,text,col);
     }
     void writeCodeLink(const char *ref,const char *file,
-                               const char *anchor,const char *name) 
+                       const char *anchor,const char *name,
+                       const char *tooltip) 
     {
       XML_DB(("(writeCodeLink)\n"));
       if (m_insideCodeLine && !m_insideSpecialHL && m_normalHLNeedStartTag)
@@ -250,7 +297,7 @@ class XMLCodeGenerator : public CodeOutputInterface
         m_t << "<highlight class=\"normal\">";
         m_normalHLNeedStartTag=FALSE;
       }
-      writeXMLLink(m_t,ref,file,anchor,name);
+      writeXMLLink(m_t,ref,file,anchor,name,tooltip);
       col+=strlen(name);
     }
     void startCodeLine() 
@@ -346,6 +393,10 @@ class XMLCodeGenerator : public CodeOutputInterface
         if (extRef) m_external=extRef;
       }
     }
+    void linkableSymbol(int, const char *,Definition *,Definition *) 
+    {
+    }
+
     void finish()
     {
       if (m_insideCodeLine) endCodeLine();
@@ -406,9 +457,10 @@ static void writeTemplateArgumentList(ArgumentList *al,
 
 static void writeMemberTemplateLists(MemberDef *md,QTextStream &t)
 {
-  if (md->templateArguments()) // function template prefix
+  LockingPtr<ArgumentList> templMd = md->templateArguments();
+  if (templMd!=0) // function template prefix
   {
-    writeTemplateArgumentList(md->templateArguments(),t,md->getClassDef(),md->getFileDef(),8);
+    writeTemplateArgumentList(templMd.pointer(),t,md->getClassDef(),md->getFileDef(),8);
   }
 }
 
@@ -487,6 +539,7 @@ static void stripQualifiers(QCString &typeStr)
     if (typeStr.stripPrefix("static "));
     else if (typeStr.stripPrefix("virtual "));
     else if (typeStr.stripPrefix("volatile "));
+    else if (typeStr=="virtual") typeStr="";
     else done=TRUE;
   }
 }
@@ -510,6 +563,8 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   
   // enum values are written as part of the enum
   if (md->memberType()==MemberDef::EnumValue) return;
+  if (md->isHidden()) return;
+  if (md->name().at(0)=='@') return; // anonymous member
 
   // group members are only visible in their group
   //if (def->definitionType()!=Definition::TypeGroup && md->getGroupDef()) return;
@@ -527,7 +582,6 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     case MemberDef::Enumeration: memType="enum";      break;
     case MemberDef::Function:    memType="function";  isFunc=TRUE; break;
     case MemberDef::Signal:      memType="signal";    isFunc=TRUE; break;
-    case MemberDef::Prototype:   memType="prototype"; isFunc=TRUE; break;
     case MemberDef::Friend:      memType="friend";    isFunc=TRUE; break;
     case MemberDef::DCOP:        memType="dcop";      isFunc=TRUE; break;
     case MemberDef::Slot:        memType="slot";      isFunc=TRUE; break;
@@ -572,9 +626,9 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
 
   if (isFunc)
   {
-    ArgumentList *al = md->argumentList();
+    LockingPtr<ArgumentList> al = md->argumentList();
     t << " const=\"";
-    if (al && al->constSpecifier)    t << "yes"; else t << "no"; 
+    if (al!=0 && al->constSpecifier)    t << "yes"; else t << "no"; 
     t << "\"";
 
     t << " explicit=\"";
@@ -585,6 +639,21 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     if (md->isInline()) t << "yes"; else t << "no";
     t << "\"";
 
+    if (md->isFinal())
+    {
+      t << " final=\"yes\"";
+    }
+
+    if (md->isSealed())
+    {
+      t << " sealed=\"yes\"";
+    }
+
+    if (md->isNew())
+    {
+      t << " new=\"yes\"";
+    }
+
     t << " virt=\"";
     switch (md->virtualness())
     {
@@ -605,6 +674,12 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     t << " mutable=\"";
     if (md->isMutable()) t << "yes"; else t << "no";
     t << "\"";
+    
+    if (md->isInitonly())
+    {
+      t << " initonly=\"yes\"";
+    }
+    
   }
   else if (md->memberType() == MemberDef::Property)
   {
@@ -612,11 +687,32 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     if (md->isReadable()) t << "yes"; else t << "no";
     t << "\"";
 
-    t << "\" writable=\"";
+    t << " writable=\"";
     if (md->isWritable()) t << "yes"; else t << "no";
     t << "\"";
-  }
 
+    t << " gettable=\"";
+    if (md->isGettable()) t << "yes"; else t << "no";
+    t << "\"";
+
+    t << " settable=\"";
+    if (md->isSettable()) t << "yes"; else t << "no";
+    t << "\"";
+  }
+  else if (md->memberType() == MemberDef::Event)
+  {
+    t << " add=\"";
+    if (md->isAddable()) t << "yes"; else t << "no";
+    t << "\"";
+
+    t << " remove=\"";
+    if (md->isRemovable()) t << "yes"; else t << "no";
+    t << "\"";
+
+    t << " raise=\"";
+    if (md->isRaisable()) t << "yes"; else t << "no";
+    t << "\"";
+  }
 
   t << ">" << endl;
 
@@ -646,6 +742,12 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     if (md->isWritable())
       t << "        <write>" << convertToXML(md->getWriteAccessor()) << "</write>" << endl;
   }
+  if (md->memberType()==MemberDef::Variable && md->bitfieldString())
+  {
+    QCString bitfield = md->bitfieldString();
+    if (bitfield.at(0)==':') bitfield=bitfield.mid(1);
+    t << "        <bitfield>" << bitfield << "</bitfield>" << endl;
+  }
   
   MemberDef *rmd = md->reimplements();
   if (rmd)
@@ -654,8 +756,8 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       << rmd->getOutputFileBase() << "_1" << rmd->anchor() << "\">"
       << convertToXML(rmd->name()) << "</reimplements>" << endl;
   }
-  MemberList *rbml = md->reimplementedBy();
-  if (rbml)
+  LockingPtr<MemberList> rbml = md->reimplementedBy();
+  if (rbml!=0)
   {
     MemberListIterator mli(*rbml);
     for (mli.toFirst();(rmd=mli.current());++mli)
@@ -668,9 +770,9 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
 
   if (isFunc) //function
   {
-    ArgumentList *declAl = md->declArgumentList();
-    ArgumentList *defAl = md->argumentList();
-    if (declAl && declAl->count()>0)
+    LockingPtr<ArgumentList> declAl = md->declArgumentList();
+    LockingPtr<ArgumentList> defAl = md->argumentList();
+    if (declAl!=0 && declAl->count()>0)
     {
       ArgumentListIterator declAli(*declAl);
       ArgumentListIterator defAli(*defAl);
@@ -763,9 +865,10 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   
   if (md->memberType()==MemberDef::Enumeration) // enum
   {
-    if (md->enumFieldList())
+    LockingPtr<MemberList> enumFields = md->enumFieldList();
+    if (enumFields!=0)
     {
-      MemberListIterator emli(*md->enumFieldList());
+      MemberListIterator emli(*enumFields);
       MemberDef *emd;
       for (emli.toFirst();(emd=emli.current());++emli)
       {
@@ -830,18 +933,20 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   }
 
   //printf("md->getReferencesMembers()=%p\n",md->getReferencesMembers());
-  if (md->getReferencesMembers())
+  LockingPtr<MemberSDict> mdict = md->getReferencesMembers();
+  if (mdict!=0)
   {
-    MemberSDict::Iterator mdi(*md->getReferencesMembers());
+    MemberSDict::Iterator mdi(*mdict);
     MemberDef *rmd;
     for (mdi.toFirst();(rmd=mdi.current());++mdi)
     {
       writeMemberReference(t,def,rmd,"references");
     }
   }
-  if (md->getReferencedByMembers())
+  mdict = md->getReferencedByMembers();
+  if (mdict!=0)
   {
-    MemberSDict::Iterator mdi(*md->getReferencedByMembers());
+    MemberSDict::Iterator mdi(*mdict);
     MemberDef *rmd;
     for (mdi.toFirst();(rmd=mdi.current());++mdi)
     {
@@ -856,6 +961,7 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
                       MemberList *ml,const char *kind,const char *header=0,
                       const char *documentation=0)
 {
+  if (ml==0) return;
   MemberListIterator mli(*ml);
   MemberDef *md;
   int count=0;
@@ -896,40 +1002,46 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
 static void writeListOfAllMembers(ClassDef *cd,QTextStream &t)
 {
   t << "    <listofallmembers>" << endl;
-  MemberNameInfoSDict::Iterator mnii(*cd->memberNameInfoSDict());
-  MemberNameInfo *mni;
-  for (mnii.toFirst();(mni=mnii.current());++mnii)
+  if (cd->memberNameInfoSDict())
   {
-    MemberNameInfoIterator mii(*mni);
-    MemberInfo *mi;
-    for (mii.toFirst();(mi=mii.current());++mii)
+    MemberNameInfoSDict::Iterator mnii(*cd->memberNameInfoSDict());
+    MemberNameInfo *mni;
+    for (mnii.toFirst();(mni=mnii.current());++mnii)
     {
-      MemberDef *md=mi->memberDef;
-      Protection prot = mi->prot;
-      Specifier virt=md->virtualness();
-      t << "      <member refid=\"" << md->getOutputFileBase() << "_1" <<
-        md->anchor() << "\" prot=\"";
-      switch (prot)
+      MemberNameInfoIterator mii(*mni);
+      MemberInfo *mi;
+      for (mii.toFirst();(mi=mii.current());++mii)
       {
-        case Public:    t << "public";    break;
-        case Protected: t << "protected"; break;
-        case Private:   t << "private";   break;
-        case Package:   t << "package";   break;
+        MemberDef *md=mi->memberDef;
+        if (md->name().at(0)!='@') // skip anonymous members
+        {
+          Protection prot = mi->prot;
+          Specifier virt=md->virtualness();
+          t << "      <member refid=\"" << md->getOutputFileBase() << "_1" <<
+            md->anchor() << "\" prot=\"";
+          switch (prot)
+          {
+            case Public:    t << "public";    break;
+            case Protected: t << "protected"; break;
+            case Private:   t << "private";   break;
+            case Package:   t << "package";   break;
+          }
+          t << "\" virt=\"";
+          switch(virt)
+          {
+            case Normal:  t << "non-virtual";  break;
+            case Virtual: t << "virtual";      break;
+            case Pure:    t << "pure-virtual"; break;
+          }
+          t << "\"";
+          if (!mi->ambiguityResolutionScope.isEmpty())
+          {
+            t << " ambiguityscope=\"" << convertToXML(mi->ambiguityResolutionScope) << "\"";
+          }
+          t << "><scope>" << convertToXML(cd->name()) << "</scope><name>" << 
+            convertToXML(md->name()) << "</name></member>" << endl;
+        }
       }
-      t << "\" virt=\"";
-      switch(virt)
-      {
-        case Normal:  t << "non-virtual";  break;
-        case Virtual: t << "virtual";      break;
-        case Pure:    t << "pure-virtual"; break;
-      }
-      t << "\"";
-      if (!mi->ambiguityResolutionScope.isEmpty())
-      {
-        t << " ambiguityscope=\"" << convertToXML(mi->ambiguityResolutionScope) << "\"";
-      }
-      t << "><scope>" << convertToXML(cd->name()) << "</scope><name>" << 
-           convertToXML(md->name()) << "</name></member>" << endl;
     }
   }
   t << "    </listofallmembers>" << endl;
@@ -943,10 +1055,18 @@ static void writeInnerClasses(const ClassSDict *cl,QTextStream &t)
     ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
     {
-      if (cd->name().find('@')==-1) // skip anonymous scopes
+      if (!cd->isHidden() && cd->name().find('@')==-1) // skip anonymous scopes
       {
         t << "    <innerclass refid=\"" << cd->getOutputFileBase()
-          << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
+          << "\" prot=\"";
+        switch(cd->protection())
+        {
+           case Public:    t << "public";     break;
+           case Protected: t << "protected";  break;
+           case Private:   t << "private";    break;
+           case Package:   t << "package";    break;
+        }
+        t << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
       }
     }
   }
@@ -960,7 +1080,7 @@ static void writeInnerNamespaces(const NamespaceSDict *nl,QTextStream &t)
     NamespaceDef *nd;
     for (nli.toFirst();(nd=nli.current());++nli)
     {
-      if (nd->name().find('@')==-1) // skip anonymouse scopes
+      if (!nd->isHidden() && nd->name().find('@')==-1) // skip anonymouse scopes
       {
         t << "    <innernamespace refid=\"" << nd->getOutputFileBase()
           << "\">" << convertToXML(nd->name()) << "</innernamespace>" << endl;
@@ -1050,9 +1170,12 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   // - examples using the class
   
   if (cd->isReference())        return; // skip external references.
+  if (cd->isHidden())           return; // skip hidden classes.
   if (cd->name().find('@')!=-1) return; // skip anonymous compounds.
   if (cd->templateMaster()!=0)  return; // skip generated template instances.
 
+  msg("Generating XML output for class %s\n",cd->name().data());
+
   ti << "  <compound refid=\"" << cd->getOutputFileBase() 
      << "\" kind=\"" << cd->compoundTypeString()
      << "\"><name>" << convertToXML(cd->name()) << "</name>" << endl;
@@ -1066,7 +1189,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
@@ -1083,7 +1206,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   t << "    <compoundname>"; 
   writeXMLString(t,cd->name()); 
   t << "</compoundname>" << endl;
-  if (cd->baseClasses()->count()>0)
+  if (cd->baseClasses())
   {
     BaseClassListIterator bcli(*cd->baseClasses());
     BaseClassDef *bcd;
@@ -1112,19 +1235,19 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
       t << "\">";
       if (!bcd->templSpecifiers.isEmpty())
       {
-        convertToXML(
-            insertTemplateSpecifierInScope(
-              bcd->classDef->displayName(),bcd->templSpecifiers)
+        t << convertToXML(
+              insertTemplateSpecifierInScope(
+              bcd->classDef->name(),bcd->templSpecifiers)
            );
       }
       else
       {
-        convertToXML(bcd->classDef->displayName());
+        t << convertToXML(bcd->classDef->displayName());
       }
       t  << "</basecompoundref>" << endl;
     }
   }
-  if (cd->subClasses()->count()>0)
+  if (cd->subClasses())
   {
     BaseClassListIterator bcli(*cd->subClasses());
     BaseClassDef *bcd;
@@ -1173,43 +1296,57 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   writeInnerClasses(cd->getInnerClasses(),t);
 
   writeTemplateList(cd,t);
-  MemberGroupSDict::Iterator mgli(*cd->memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (cd->getMemberGroupSDict())
   {
-    generateXMLSection(cd,ti,t,mg->members(),"user-defined",mg->header(),
-                       mg->documentation());
+    MemberGroupSDict::Iterator mgli(*cd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      generateXMLSection(cd,ti,t,mg->members(),"user-defined",mg->header(),
+          mg->documentation());
+    }
   }
 
-  generateXMLSection(cd,ti,t,&cd->pubTypes,"public-type");
-  generateXMLSection(cd,ti,t,&cd->pubMethods,"public-func");
-  generateXMLSection(cd,ti,t,&cd->pubAttribs,"public-attrib");
-  generateXMLSection(cd,ti,t,&cd->pubSlots,"public-slot");
-  generateXMLSection(cd,ti,t,&cd->signals,"signal");
-  generateXMLSection(cd,ti,t,&cd->dcopMethods,"dcop-func");
-  generateXMLSection(cd,ti,t,&cd->properties,"property");
-  generateXMLSection(cd,ti,t,&cd->events,"event");
-  generateXMLSection(cd,ti,t,&cd->pubStaticMethods,"public-static-func");
-  generateXMLSection(cd,ti,t,&cd->pubStaticAttribs,"public-static-attrib");
-  generateXMLSection(cd,ti,t,&cd->proTypes,"protected-type");
-  generateXMLSection(cd,ti,t,&cd->proMethods,"protected-func");
-  generateXMLSection(cd,ti,t,&cd->proAttribs,"protected-attrib");
-  generateXMLSection(cd,ti,t,&cd->proSlots,"protected-slot");
-  generateXMLSection(cd,ti,t,&cd->proStaticMethods,"protected-static-func");
-  generateXMLSection(cd,ti,t,&cd->proStaticAttribs,"protected-static-attrib");
-  generateXMLSection(cd,ti,t,&cd->pacTypes,"package-type");
-  generateXMLSection(cd,ti,t,&cd->pacMethods,"package-func");
-  generateXMLSection(cd,ti,t,&cd->pacAttribs,"package-attrib");
-  generateXMLSection(cd,ti,t,&cd->pacStaticMethods,"package-static-func");
-  generateXMLSection(cd,ti,t,&cd->pacStaticAttribs,"package-static-attrib");
-  generateXMLSection(cd,ti,t,&cd->priTypes,"private-type");
-  generateXMLSection(cd,ti,t,&cd->priMethods,"private-func");
-  generateXMLSection(cd,ti,t,&cd->priAttribs,"private-attrib");
-  generateXMLSection(cd,ti,t,&cd->priSlots,"private-slot");
-  generateXMLSection(cd,ti,t,&cd->priStaticMethods,"private-static-func");
-  generateXMLSection(cd,ti,t,&cd->priStaticAttribs,"private-static-attrib");
-  generateXMLSection(cd,ti,t,&cd->friends,"friend");
-  generateXMLSection(cd,ti,t,&cd->related,"related");
+  QListIterator<MemberList> mli(cd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::detailedLists)==0)
+    {
+      generateXMLSection(cd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
+    }
+  }
+#if 0
+  generateXMLSection(cd,ti,t,cd->pubTypes,"public-type");
+  generateXMLSection(cd,ti,t,cd->pubMethods,"public-func");
+  generateXMLSection(cd,ti,t,cd->pubAttribs,"public-attrib");
+  generateXMLSection(cd,ti,t,cd->pubSlots,"public-slot");
+  generateXMLSection(cd,ti,t,cd->signals,"signal");
+  generateXMLSection(cd,ti,t,cd->dcopMethods,"dcop-func");
+  generateXMLSection(cd,ti,t,cd->properties,"property");
+  generateXMLSection(cd,ti,t,cd->events,"event");
+  generateXMLSection(cd,ti,t,cd->pubStaticMethods,"public-static-func");
+  generateXMLSection(cd,ti,t,cd->pubStaticAttribs,"public-static-attrib");
+  generateXMLSection(cd,ti,t,cd->proTypes,"protected-type");
+  generateXMLSection(cd,ti,t,cd->proMethods,"protected-func");
+  generateXMLSection(cd,ti,t,cd->proAttribs,"protected-attrib");
+  generateXMLSection(cd,ti,t,cd->proSlots,"protected-slot");
+  generateXMLSection(cd,ti,t,cd->proStaticMethods,"protected-static-func");
+  generateXMLSection(cd,ti,t,cd->proStaticAttribs,"protected-static-attrib");
+  generateXMLSection(cd,ti,t,cd->pacTypes,"package-type");
+  generateXMLSection(cd,ti,t,cd->pacMethods,"package-func");
+  generateXMLSection(cd,ti,t,cd->pacAttribs,"package-attrib");
+  generateXMLSection(cd,ti,t,cd->pacStaticMethods,"package-static-func");
+  generateXMLSection(cd,ti,t,cd->pacStaticAttribs,"package-static-attrib");
+  generateXMLSection(cd,ti,t,cd->priTypes,"private-type");
+  generateXMLSection(cd,ti,t,cd->priMethods,"private-func");
+  generateXMLSection(cd,ti,t,cd->priAttribs,"private-attrib");
+  generateXMLSection(cd,ti,t,cd->priSlots,"private-slot");
+  generateXMLSection(cd,ti,t,cd->priStaticMethods,"private-static-func");
+  generateXMLSection(cd,ti,t,cd->priStaticAttribs,"private-static-attrib");
+  generateXMLSection(cd,ti,t,cd->friends,"friend");
+  generateXMLSection(cd,ti,t,cd->related,"related");
+#endif
 
   t << "    <briefdescription>" << endl;
   writeXMLDocBlock(t,cd->briefFile(),cd->briefLine(),cd,0,cd->briefDescription());
@@ -1217,16 +1354,14 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   t << "    <detaileddescription>" << endl;
   writeXMLDocBlock(t,cd->docFile(),cd->docLine(),cd,0,cd->documentation());
   t << "    </detaileddescription>" << endl;
-  DotClassGraph inheritanceGraph(cd,DotNode::Inheritance,
-                                 Config_getInt("MAX_DOT_GRAPH_DEPTH"));
+  DotClassGraph inheritanceGraph(cd,DotNode::Inheritance);
   if (!inheritanceGraph.isTrivial())
   {
     t << "    <inheritancegraph>" << endl;
     inheritanceGraph.writeXML(t);
     t << "    </inheritancegraph>" << endl;
   }
-  DotClassGraph collaborationGraph(cd,DotNode::Collaboration,
-                                 Config_getInt("MAX_DOT_GRAPH_DEPTH"));
+  DotClassGraph collaborationGraph(cd,DotNode::Collaboration);
   if (!collaborationGraph.isTrivial())
   {
     t << "    <collaborationgraph>" << endl;
@@ -1265,7 +1400,7 @@ static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
   // + location
   // - files containing (parts of) the namespace definition
 
-  if (nd->isReference()) return; // skip external references
+  if (nd->isReference() || nd->isHidden()) return; // skip external references
 
   ti << "  <compound refid=\"" << nd->getOutputFileBase() 
      << "\" kind=\"namespace\"" << "><name>" 
@@ -1280,7 +1415,7 @@ static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
   
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
@@ -1289,23 +1424,37 @@ static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
   writeXMLString(t,nd->name());
   t << "</compoundname>" << endl;
 
-  writeInnerClasses(nd->classSDict,t);
-  writeInnerNamespaces(nd->namespaceSDict,t);
+  writeInnerClasses(nd->getClassSDict(),t);
+  writeInnerNamespaces(nd->getNamespaceSDict(),t);
 
-  MemberGroupSDict::Iterator mgli(*nd->memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (nd->getMemberGroupSDict())
   {
-    generateXMLSection(nd,ti,t,mg->members(),"user-defined",mg->header(),
-                       mg->documentation());
+    MemberGroupSDict::Iterator mgli(*nd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      generateXMLSection(nd,ti,t,mg->members(),"user-defined",mg->header(),
+          mg->documentation());
+    }
   }
 
+  QListIterator<MemberList> mli(nd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::declarationLists)!=0)
+    {
+      generateXMLSection(nd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
+    }
+  }
+#if 0
   generateXMLSection(nd,ti,t,&nd->decDefineMembers,"define");
   generateXMLSection(nd,ti,t,&nd->decProtoMembers,"prototype");
   generateXMLSection(nd,ti,t,&nd->decTypedefMembers,"typedef");
   generateXMLSection(nd,ti,t,&nd->decEnumMembers,"enum");
   generateXMLSection(nd,ti,t,&nd->decFuncMembers,"func");
   generateXMLSection(nd,ti,t,&nd->decVarMembers,"var");
+#endif
 
   t << "    <briefdescription>" << endl;
   writeXMLDocBlock(t,nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription());
@@ -1353,7 +1502,7 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
@@ -1362,34 +1511,41 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
   writeXMLString(t,fd->name());
   t << "</compoundname>" << endl;
 
-  QListIterator<IncludeInfo> ili1(*fd->includeFileList());
   IncludeInfo *inc;
-  for (ili1.toFirst();(inc=ili1.current());++ili1)
+
+  if (fd->includeFileList())
   {
-    t << "    <includes";
-    if (inc->fileDef && !inc->fileDef->isReference()) // TODO: support external references
+    QListIterator<IncludeInfo> ili1(*fd->includeFileList());
+    for (ili1.toFirst();(inc=ili1.current());++ili1)
     {
-      t << " refid=\"" << inc->fileDef->getOutputFileBase() << "\"";
+      t << "    <includes";
+      if (inc->fileDef && !inc->fileDef->isReference()) // TODO: support external references
+      {
+        t << " refid=\"" << inc->fileDef->getOutputFileBase() << "\"";
+      }
+      t << " local=\"" << (inc->local ? "yes" : "no") << "\">";
+      t << inc->includeName;
+      t << "</includes>" << endl;
     }
-    t << " local=\"" << (inc->local ? "yes" : "no") << "\">";
-    t << inc->includeName;
-    t << "</includes>" << endl;
   }
 
-  QListIterator<IncludeInfo> ili2(*fd->includedByFileList());
-  for (ili2.toFirst();(inc=ili2.current());++ili2)
+  if (fd->includedByFileList())
   {
-    t << "    <includedby";
-    if (inc->fileDef && !inc->fileDef->isReference()) // TODO: support external references
+    QListIterator<IncludeInfo> ili2(*fd->includedByFileList());
+    for (ili2.toFirst();(inc=ili2.current());++ili2)
     {
-      t << " refid=\"" << inc->fileDef->getOutputFileBase() << "\"";
+      t << "    <includedby";
+      if (inc->fileDef && !inc->fileDef->isReference()) // TODO: support external references
+      {
+        t << " refid=\"" << inc->fileDef->getOutputFileBase() << "\"";
+      }
+      t << " local=\"" << (inc->local ? "yes" : "no") << "\">";
+      t << inc->includeName;
+      t << "</includedby>" << endl;
     }
-    t << " local=\"" << (inc->local ? "yes" : "no") << "\">";
-    t << inc->includeName;
-    t << "</includedby>" << endl;
   }
 
-  DotInclDepGraph incDepGraph(fd,Config_getInt("MAX_DOT_GRAPH_DEPTH"),FALSE);
+  DotInclDepGraph incDepGraph(fd,FALSE);
   if (!incDepGraph.isTrivial())
   {
     t << "    <incdepgraph>" << endl;
@@ -1397,7 +1553,7 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
     t << "    </incdepgraph>" << endl;
   }
 
-  DotInclDepGraph invIncDepGraph(fd,Config_getInt("MAX_DOT_GRAPH_DEPTH"),TRUE);
+  DotInclDepGraph invIncDepGraph(fd,TRUE);
   if (!invIncDepGraph.isTrivial())
   {
     t << "    <invincdepgraph>" << endl;
@@ -1405,23 +1561,43 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
     t << "    </invincdepgraph>" << endl;
   }
 
-  writeInnerClasses(fd->classSDict,t);
-  writeInnerNamespaces(fd->namespaceSDict,t);
-
-  MemberGroupSDict::Iterator mgli(*fd->memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (fd->getClassSDict())
   {
-    generateXMLSection(fd,ti,t,mg->members(),"user-defined",mg->header(),
-                       mg->documentation());
+    writeInnerClasses(fd->getClassSDict(),t);
+  }
+  if (fd->getNamespaceSDict())
+  {
+    writeInnerNamespaces(fd->getNamespaceSDict(),t);
   }
 
-  generateXMLSection(fd,ti,t,&fd->decDefineMembers,"define");
-  generateXMLSection(fd,ti,t,&fd->decProtoMembers,"prototype");
-  generateXMLSection(fd,ti,t,&fd->decTypedefMembers,"typedef");
-  generateXMLSection(fd,ti,t,&fd->decEnumMembers,"enum");
-  generateXMLSection(fd,ti,t,&fd->decFuncMembers,"func");
-  generateXMLSection(fd,ti,t,&fd->decVarMembers,"var");
+  if (fd->getMemberGroupSDict())
+  {
+    MemberGroupSDict::Iterator mgli(*fd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      generateXMLSection(fd,ti,t,mg->members(),"user-defined",mg->header(),
+          mg->documentation());
+    }
+  }
+
+  QListIterator<MemberList> mli(fd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::declarationLists)!=0)
+    {
+      generateXMLSection(fd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
+    }
+  }
+#if 0
+  generateXMLSection(fd,ti,t,fd->decDefineMembers,"define");
+  generateXMLSection(fd,ti,t,fd->decProtoMembers,"prototype");
+  generateXMLSection(fd,ti,t,fd->decTypedefMembers,"typedef");
+  generateXMLSection(fd,ti,t,fd->decEnumMembers,"enum");
+  generateXMLSection(fd,ti,t,fd->decFuncMembers,"func");
+  generateXMLSection(fd,ti,t,fd->decVarMembers,"var");
+#endif
 
   t << "    <briefdescription>" << endl;
   writeXMLDocBlock(t,fd->briefFile(),fd->briefLine(),fd,0,fd->briefDescription());
@@ -1471,7 +1647,7 @@ static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
   }
 
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
     << gd->getOutputFileBase() << "\" kind=\"group\">" << endl;
@@ -1484,20 +1660,34 @@ static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
   writeInnerPages(gd->getPages(),t);
   writeInnerGroups(gd->getSubGroups(),t);
 
-  MemberGroupSDict::Iterator mgli(*gd->memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (gd->getMemberGroupSDict())
   {
-    generateXMLSection(gd,ti,t,mg->members(),"user-defined",mg->header(),
-                       mg->documentation());
+    MemberGroupSDict::Iterator mgli(*gd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      generateXMLSection(gd,ti,t,mg->members(),"user-defined",mg->header(),
+          mg->documentation());
+    }
   }
 
+  QListIterator<MemberList> mli(gd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::declarationLists)!=0)
+    {
+      generateXMLSection(gd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
+    }
+  }
+#if 0
   generateXMLSection(gd,ti,t,&gd->decDefineMembers,"define");
   generateXMLSection(gd,ti,t,&gd->decProtoMembers,"prototype");
   generateXMLSection(gd,ti,t,&gd->decTypedefMembers,"typedef");
   generateXMLSection(gd,ti,t,&gd->decEnumMembers,"enum");
   generateXMLSection(gd,ti,t,&gd->decFuncMembers,"func");
   generateXMLSection(gd,ti,t,&gd->decVarMembers,"var");
+#endif
 
   t << "    <briefdescription>" << endl;
   writeXMLDocBlock(t,gd->briefFile(),gd->briefLine(),gd,0,gd->briefDescription());
@@ -1528,7 +1718,7 @@ static void generateXMLForDir(DirDef *dd,QTextStream &ti)
   }
 
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
     << dd->getOutputFileBase() << "\" kind=\"dir\">" << endl;
@@ -1581,14 +1771,14 @@ static void generateXMLForPage(PageDef *pd,QTextStream &ti,bool isExample)
   }
 
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" << pageName;
   t << "\" kind=\"" << kindName << "\">" << endl;
   t << "    <compoundname>" << convertToXML(pd->name()) 
     << "</compoundname>" << endl;
 
-  SectionInfo *si = Doxygen::sectionDict.find(pageName);
+  SectionInfo *si = Doxygen::sectionDict.find(pd->name());
   if (si)
   {
     t << "    <title>" << convertToXML(si->title) << "</title>" << endl;
@@ -1689,21 +1879,19 @@ void generateXML()
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   // write index header
-  t << "<?xml version='1.0' encoding='" << theTranslator->idLanguageCharset()
-    << "' standalone='no'?>" << endl;;
+  t << "<?xml version='1.0' encoding='UTF-8' standalone='no'?>" << endl;;
   t << "<doxygenindex xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" ";
   t << "xsi:noNamespaceSchemaLocation=\"index.xsd\" ";
   t << "version=\"" << versionString << "\">" << endl;
 
   {
-    ClassSDict::Iterator cli(Doxygen::classSDict);
+    ClassSDict::Iterator cli(*Doxygen::classSDict);
     ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
     {
-      msg("Generating XML output for class %s\n",cd->name().data());
       generateXMLForClass(cd,t);
     }
   }
@@ -1716,14 +1904,14 @@ void generateXML()
   //    generateXMLForClass(cd,t);
   //  }
   //}
-  NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
+  NamespaceSDict::Iterator nli(*Doxygen::namespaceSDict);
   NamespaceDef *nd;
   for (nli.toFirst();(nd=nli.current());++nli)
   {
     msg("Generating XML output for namespace %s\n",nd->name().data());
     generateXMLForNamespace(nd,t);
   }
-  FileNameListIterator fnli(Doxygen::inputNameList);
+  FileNameListIterator fnli(*Doxygen::inputNameList);
   FileName *fn;
   for (;(fn=fnli.current());++fnli)
   {
@@ -1735,7 +1923,7 @@ void generateXML()
       generateXMLForFile(fd,t);
     }
   }
-  GroupSDict::Iterator gli(Doxygen::groupSDict);
+  GroupSDict::Iterator gli(*Doxygen::groupSDict);
   GroupDef *gd;
   for (;(gd=gli.current());++gli)
   {
@@ -1753,7 +1941,7 @@ void generateXML()
   }
   {
     DirDef *dir;
-    DirSDict::Iterator sdi(Doxygen::directories);
+    DirSDict::Iterator sdi(*Doxygen::directories);
     for (sdi.toFirst();(dir=sdi.current());++sdi)
     {
       msg("Generate XML output for dir %s\n",dir->name().data());
